@@ -1,21 +1,53 @@
 OC.L10N.register(
     "contacts",
     {
-    "Contacts" : "Contactos",
-    "All contacts" : "Todos los contactos",
     "Details" : "Detalles",
+    "All contacts" : "Todos los contactos",
+    "Contacts" : "Contactos",
+    "Loading contacts …" : "Cargando contactos ...",
+    "Delete circle" : "Borrar círculo",
     "Download" : "Descargar",
-    "Delete" : "Borrar",
+    "Send email" : "Enviar correo electrónico",
     "Groups" : "Grupos",
-    "New contact" : "Nuevo contacto",
+    "Group name" : "Nombre del grupo",
+    "Circles" : "Círculos",
+    "Create a new circle" : "Crear un nuevo círculo",
     "Rename" : "Renombrar",
     "Enabled" : "Habilitado",
-    "Disabled" : "Deshabilitado",
+    "Delete" : "Borrar",
     "Copy link" : "Copiar liga",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
-    "Import into" : "Importar a",
+    "can edit" : "puede editar",
     "First name" : "Nombre",
     "Last name" : "Apellido",
+    "Display name" : "Nombre a desplegar",
+    "Last modified" : "Última modificación",
+    "Password protection" : "Protección con contraseña",
+    "Save" : "Guardar",
+    "Description" : "Descripción",
+    "Invalid image" : "Imagen inválida",
+    "Name" : "Nombre",
+    "Title" : "Título",
+    "Cancel" : "Cancelar",
+    "Address book" : "Libreta de direcciones",
+    "New contact" : "Nuevo contacto",
+    "Search contacts …" : "Buscar contactos ...",
+    "No results" : "No hay resultados",
+    "Personal circle" : "Círculo personal",
+    "Pending" : "Pendiente",
+    "Close" : "Cerrar",
+    "Import" : "Importar",
+    "Not grouped" : "No agrupado",
+    "Circle" : "Círculo",
+    "User" : "Ususario",
+    "Group" : "Grupo",
+    "Email" : "Correo electrónico",
+    "Contact" : "Contacto",
+    "Member" : "Miembro",
+    "Moderator" : "Moderador",
+    "Admin" : "Admin",
+    "Owner" : "Dueño",
+    "Users" : "Usuarios",
     "Nickname" : "Apodo",
     "Detailed name" : "Nombre detallado",
     "Additional names" : "Nombres adicionales",
@@ -23,6 +55,7 @@ OC.L10N.register(
     "Suffix" : "Sufijo",
     "Notes" : "Notas",
     "Website" : "Sitio web",
+    "Location" : "Ubicación",
     "Federated Cloud ID" : "Id de nube federada",
     "Home" : "Particular",
     "Work" : "Trabajo",
@@ -36,7 +69,6 @@ OC.L10N.register(
     "Birthday" : "Fecha de nacimiento",
     "Anniversary" : "Aniversario",
     "Date of death" : "Fecha de defunción",
-    "Email" : "Correo electrónico",
     "Instant messaging" : "Mensajería instantánea",
     "Phone" : "Teléfono fijo",
     "Mobile" : "Teléfono móvil",
@@ -49,8 +81,6 @@ OC.L10N.register(
     "Car" : "Auto",
     "Work pager" : "Localizador de trabajo",
     "Social network" : "Red social",
-    "Relationship" : "Relación",
-    "Specify a relationship between you and the entity represented by this vCard." : "Especifica la relación entre tú y la entidad representada por esta vCard.",
     "Spouse" : "Cónyuge",
     "Child" : "Hijo",
     "Mother" : "Madre",
@@ -63,14 +93,13 @@ OC.L10N.register(
     "Colleague" : "Colega",
     "Manager" : "Gerente",
     "Assistant" : "Asistente",
-    "Related" : "Relacionado",
-    "Specify a relationship between another entity and the entity represented by this vCard." : "Especifica la relación entre alguna otra entidad y la entidad representada por esta vCard.",
-    "Contact" : "Contacto",
     "Agent" : "Agente",
     "Emergency" : "Emergencia",
     "Co-worker" : "Compañero de trabajo",
     "Gender" : "Género",
     "Female" : "Femenino",
-    "Male" : "Masculino"
+    "Male" : "Masculino",
+    "None" : "Ninguno",
+    "Unknown" : "Desconocido"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
