@@ -5,9 +5,13 @@ OC.L10N.register(
     "All contacts" : "Todos los contactos",
     "Contacts" : "Contactos",
     "Loading contacts …" : "Cargando contactos ...",
+    "Delete circle" : "Borrar círculo",
     "Download" : "Descargar",
+    "Send email" : "Enviar correo electrónico",
     "Groups" : "Grupos",
     "Group name" : "Nombre del grupo",
+    "Circles" : "Círculos",
+    "Create a new circle" : "Crear un nuevo círculo",
     "Rename" : "Renombrar",
     "Enabled" : "Habilitado",
     "Delete" : "Borrar",
@@ -18,18 +22,32 @@ OC.L10N.register(
     "Last name" : "Apellido",
     "Display name" : "Nombre a desplegar",
     "Last modified" : "Última modificación",
+    "Password protection" : "Protección con contraseña",
+    "Save" : "Guardar",
+    "Description" : "Descripción",
     "Invalid image" : "Imagen inválida",
     "Name" : "Nombre",
     "Title" : "Título",
     "Cancel" : "Cancelar",
     "Address book" : "Libreta de direcciones",
     "New contact" : "Nuevo contacto",
+    "Search contacts …" : "Buscar contactos ...",
     "No results" : "No hay resultados",
+    "Personal circle" : "Círculo personal",
+    "Pending" : "Pendiente",
     "Close" : "Cerrar",
     "Import" : "Importar",
     "Not grouped" : "No agrupado",
+    "Circle" : "Círculo",
+    "User" : "Usuario",
+    "Group" : "Grupo",
     "Email" : "Correo electrónico",
     "Contact" : "Contacto",
+    "Member" : "Miembro",
+    "Moderator" : "Moderador",
+    "Admin" : "Admin",
+    "Owner" : "Dueño",
+    "Users" : "Usuarios",
     "Nickname" : "Apodo",
     "Detailed name" : "Nombre detallado",
     "Additional names" : "Nombres adicionales",
@@ -84,4 +102,4 @@ OC.L10N.register(
     "None" : "Ninguno",
     "Unknown" : "Desconocido"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=2; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
