@@ -6,6 +6,7 @@ OC.L10N.register(
     "Contacts" : "Kontaktid",
     "Loading contacts …" : "Laen kontakte ...",
     "Download" : "Lae alla",
+    "Send email" : "Saada kiri",
     "Groups" : "Grupid",
     "Group name" : "Grupi nimi",
     "Rename" : "Nimeta ümber",
@@ -19,6 +20,9 @@ OC.L10N.register(
     "Last name" : "Perekonnanimi",
     "Display name" : "Kuvatav nimi",
     "Last modified" : "Viimati muudetud",
+    "Password protection" : "Password protection",
+    "Save" : "Salvesta",
+    "Description" : "Kirjeldus",
     "Delete picture" : "Kustuta pilt",
     "Invalid image" : "Vigane pilt",
     "Name" : "Nimi",
@@ -26,12 +30,23 @@ OC.L10N.register(
     "Cancel" : "Loobu",
     "Address book" : "Aadressiraamat",
     "New contact" : "Uus kontakt",
+    "Search contacts …" : "Otsi kontakte",
     "No results" : "Vasteid ei leitud",
+    "Personal circle" : "Isiklik ring",
+    "Pending" : "Ootel",
     "Close" : "Sulge",
     "Import" : "Impordi",
     "Not grouped" : "Pole grupeeritud",
+    "Circle" : "Ring",
+    "User" : "Kasutaja",
+    "Group" : "Grupp",
     "Email" : "E-post",
     "Contact" : "Kontakt",
+    "Member" : "Liige",
+    "Moderator" : "Moderaator",
+    "Admin" : "Admin",
+    "Owner" : "Omanik",
+    "Users" : "Kasutajad",
     "Nickname" : "Hüüdnimi",
     "Detailed name" : "Üksikasjalik nimi",
     "Additional names" : "Lisanimed",
