@@ -2,20 +2,27 @@ OC.L10N.register(
     "contacts",
     {
     "Details" : "Մանրամասներ",
-    "Name" : "Անուն",
-    "Title" : "Վերնագիր",
     "Download" : "Ներբեռնել",
-    "Delete" : "հեռացնել",
-    "Cancel" : "ընդհատել",
     "Groups" : "Խմբեր",
     "Rename" : "Վերանվանել",
+    "Delete" : "հեռացնել",
     "Copy link" : "Պատճենել հղումը",
     "Share with users or groups" : "Կիսվել օգտատերերի կամ խմբերի հետ",
     "can edit" : "կարող է խմբագրել",
     "First name" : "Անուն",
     "Last name" : "Ազգանուն",
+    "Password protection" : "Password protection",
+    "Save" : "Պահպանել",
+    "Description" : "Նկարագրություն",
+    "Name" : "Անուն",
+    "Title" : "Վերնագիր",
+    "Cancel" : "ընդհատել",
     "Close" : "Փակել",
     "Import" : "Ներմուծում",
+    "User" : "User",
+    "Group" : "Խումբ",
+    "Email" : "Էլ. հասցե",
+    "Owner" : "Owner",
     "Nickname" : "Մականուն",
     "Notes" : "Նոթեր",
     "Location" : "Տեղակայություն",
@@ -24,7 +31,6 @@ OC.L10N.register(
     "City" : "Քաղաք",
     "Country" : "Երկիր",
     "Birthday" : "Ծննդյան օր",
-    "Email" : "Էլ. հասցե",
     "Relative" : "Հարաբերական",
     "Unknown" : "Անհայտ"
 },
