@@ -25,6 +25,7 @@ OC.L10N.register(
     "Leave circle" : "サークルを退会する",
     "Delete circle" : "サークルを削除",
     "Download" : "ダウンロード",
+    "Send email" : "メールを送信",
     "Groups" : "グループ",
     "Create a new group" : "新規グループを作成",
     "Group name" : "グループ名",
@@ -73,6 +74,8 @@ OC.L10N.register(
     "(refreshed once per week)" : "(週に1回更新)",
     "Address books" : "アドレス帳",
     "An error happened during the config change" : "構成の変更中にエラーが発生しました",
+    "Password protection" : "パスワード保護",
+    "Save" : "保存",
     "Circle name" : "サークル名",
     "Circle owned by {owner}" : "{owner}が所有しているサークル",
     "Request to join" : "参加リクエスト",
@@ -85,6 +88,7 @@ OC.L10N.register(
     "Choose property type" : "プロパティの種類を選択",
     "Upload a new picture" : "新しい写真をアップロードする",
     "Choose from Files" : "ファイルから選択",
+    "Get from " : "次から入手:",
     "Download picture" : "画像をダウンロード",
     "Delete picture" : "画像を削除",
     "Invalid image" : "無効な画像",
@@ -102,6 +106,7 @@ OC.L10N.register(
     "This contact was broken and received a fix. Please review the content and click here to save it." : "この連絡先は変更され、修正を受信しました。内容を確認してクリックで保存してください。",
     "Clone contact" : "連絡先の複製",
     "Generate QR Code" : "QRコードを生成",
+    "Contact vCard as QR code" : "QRコードでの連絡先vCard",
     "Pick an address book" : "アドレス帳を選ぶ",
     "Select address book" : "アドレス帳を選ぶ",
     "Cancel" : "キャンセル",
@@ -115,6 +120,7 @@ OC.L10N.register(
     "Unable to retrieve the contact from the server, please check your network connection." : "サーバーから連絡先を取得できないので、ネットワークの接続をご確認ください。",
     "An error occurred while trying to move the contact" : "連絡先の移動中にエラーが発生しました",
     "An error occurred while trying to copy the contact" : "連絡先のコピー中にエラーが発生しました",
+    "Search contacts …" : "連絡先を検索...",
     "Add to {group}" : "{group}に追加",
     "Remove {type}" : "{type} を削除",
     "Search {types}" : "{types} を検索",
@@ -143,10 +149,12 @@ OC.L10N.register(
     "Manage level" : "レベルを管理",
     "Remove member" : "メンバーを削除",
     "Pending" : "保留中",
+    "Promote as sole owner" : "唯一の所有者に昇格",
     "Promote to {level}" : "{level}に昇格",
     "Demote to {level}" : "{level}に降格",
     "Could not delete the member {displayName}" : "メンバー{displayName}を削除できませんでした",
     "Could not change the member level to {level}" : "メンバーレベルを{level}に変更できませんでした",
+    "Could not accept membership request" : "メンバーシップリクエストを承諾できませんでした",
     "Select type" : "タイプを選択",
     "Select Date" : "日付を選択",
     "Add contact in group" : "グループに連絡先を追加",
@@ -155,6 +163,8 @@ OC.L10N.register(
     "Contact not found" : "連絡先がありません",
     "Group {group} not found" : "グループ {group} が見つかりません",
     "Close" : "閉じる",
+    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 件の連絡先を {name} に追加しました"],
+    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} 件の連絡先を {name} に追加中"],
     "_{count} error_::_{count} errors_" : ["{count} つのエラー"],
     "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n の連絡先をインポートしています。"],
     "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n 連絡先のインポートが完了しました"],
@@ -184,8 +194,13 @@ OC.L10N.register(
     "Owner" : "所有者",
     "Invites" : "招待",
     "Anyone can request membership" : "誰でもメンバーへの参加をリクエストできます",
+    "Members need to accept invitation" : "メンバーは招待を承認する必要があります",
+    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "メンバーシップは、モデレーターにより確認/承認が必要です（開く要求）",
+    "Members can also invite" : "メンバーによる招待も可能",
     "Visibility" : "公開レベル",
     "Visible to everyone" : "すべての人に公開",
+    "Circle membership" : "サークルメンバーシップ",
+    "Prevent circle from being a member of another circle" : "サークルが別のサークルのメンバーにならないようにする",
     "Users" : "ユーザー",
     "Emails" : "メール",
     "Nickname" : "ニックネーム",
