@@ -14,13 +14,22 @@ OC.L10N.register(
     "can edit" : "kann änneren",
     "First name" : "Virnumm",
     "Last name" : "Famillje Numm",
+    "Password protection" : "Password protection",
+    "Save" : "Späicheren",
+    "Description" : "Beschreiwung",
     "Invalid image" : "Ongülteg d'Bild",
     "Name" : "Numm",
     "Title" : "Titel",
     "Cancel" : "Ofbriechen",
+    "Pending" : "Ausstoend",
     "Close" : "Zoumaachen",
     "Import" : "Importéieren",
+    "User" : "User",
+    "Group" : "Grupp",
     "Email" : "Email",
+    "Admin" : "Admin",
+    "Owner" : "Owner",
+    "Users" : "Benotzer",
     "Nickname" : "Spëtznumm",
     "Additional names" : "Weider Nimm",
     "Notes" : "Notizen",
