@@ -8,12 +8,20 @@ OC.L10N.register(
     "Rename" : "ئات ئۆزگەرت",
     "Delete" : "ئۆچۈر",
     "First name" : "ئاتى",
+    "Password protection" : "Password protection",
+    "Save" : "ساقلا",
+    "Description" : "چۈشەندۈرۈش",
     "Name" : "ئاتى",
     "Title" : "ماۋزۇ",
     "Cancel" : "ۋاز كەچ",
+    "Pending" : "كۈتۈۋاتىدۇ",
     "Close" : "ياپ",
     "Import" : "ئەكىر",
+    "User" : "User",
+    "Group" : "Group",
     "Email" : "تورخەت",
+    "Owner" : "Owner",
+    "Users" : "ئىشلەتكۈچىلەر",
     "Nickname" : "تەخەللۇس",
     "Notes" : "ئىزاھاتلار",
     "Location" : "ئورنى",
