@@ -2,14 +2,20 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "Kontaktlar",
-    "Invalid image" : "Tasdiqlanmagan tasvir",
-    "Name" : "Ism...",
+    "Loading contacts …" : "Kontakt yuklanmoqda…",
     "Download" : "Yuklab oling",
-    "Delete" : "O'chir",
-    "Cancel" : "Bekor qilish",
     "Groups" : "Guruhlar",
     "Rename" : "Nomni o'zgartiring",
-    "Loading contacts …" : "Kontakt yuklanmoqda…",
+    "Delete" : "O'chir",
+    "Save" : "Saqlash",
+    "Invalid image" : "Tasdiqlanmagan tasvir",
+    "Name" : "Ism...",
+    "Cancel" : "Bekor qilish",
+    "Search contacts …" : "Kontaktlarni qidirish ...",
+    "Pending" : "Kutilmoqda",
+    "Member" : "Ro'yxatdan",
+    "Admin" : "Admin",
+    "Users" : "Foydalanuvchilar",
     "Notes" : "Eslatmalar",
     "Unknown" : "Noma'lum"
 },
