@@ -25,6 +25,7 @@ OC.L10N.register(
     "Leave circle" : "离开圈子",
     "Delete circle" : "删除圈子",
     "Download" : "下载",
+    "Send email" : "发送邮件",
     "Groups" : "群组",
     "Create a new group" : "新建一个群组",
     "Group name" : "分组名称",
@@ -73,6 +74,8 @@ OC.L10N.register(
     "(refreshed once per week)" : "(每周刷新)",
     "Address books" : "通讯录",
     "An error happened during the config change" : "更改配置时发生一个错误",
+    "Password protection" : "密码保护",
+    "Save" : "保存",
     "Circle name" : "圈子名称",
     "Circle owned by {owner}" : "圈子所有者为  {owner}",
     "Request to join" : "请求加入",
@@ -117,6 +120,7 @@ OC.L10N.register(
     "Unable to retrieve the contact from the server, please check your network connection." : "无法从服务器取回联系人，请检查你的网络连接。",
     "An error occurred while trying to move the contact" : "尝试移动联系人时出错",
     "An error occurred while trying to copy the contact" : "尝试复制联系人时出错",
+    "Search contacts …" : "搜索联系人 …",
     "Add to {group}" : "添加到 {group}",
     "Remove {type}" : "移除 {类型}",
     "Search {types}" : "搜索 {类型}",
