@@ -74,6 +74,13 @@ OC.L10N.register(
     "(refreshed once per week)" : "（每週重新整理一次）",
     "Address books" : "通訊錄",
     "An error happened during the config change" : "變更設定時發生錯誤",
+    "Password protection" : "密碼保護",
+    "Enforce password protection on files shared to this circle" : "對分享到此小圈圈的檔案加上密碼保護",
+    "Use a unique password for all shares to this circles" : "對此小圈圈的所有分享使用獨一無二的密碼",
+    "Unique password …" : "獨一無二的密碼……",
+    "Save" : "儲存",
+    "Change unique password" : "變更獨一無二的密碼",
+    "Failed to save password. Please try again later." : "儲存密碼失敗。請稍後再試。",
     "Circle name" : "小圈圈名稱",
     "Circle owned by {owner}" : "{owner} 擁有的小圈圈",
     "Request to join" : "要求加入",
@@ -118,6 +125,7 @@ OC.L10N.register(
     "Unable to retrieve the contact from the server, please check your network connection." : "無法從伺服器擷取聯絡人，請檢查您的網路連線。",
     "An error occurred while trying to move the contact" : "嘗試移動聯絡人時發生錯誤",
     "An error occurred while trying to copy the contact" : "嘗試複製聯絡人時發生錯誤",
+    "Search contacts …" : "搜尋聯絡人……",
     "Add to {group}" : "新增至 {group}",
     "Remove {type}" : "移除 {type}",
     "Search {types}" : "搜尋 {types}",
